@@ -12,7 +12,10 @@ use serde::{Deserialize, Serialize};
 ///
 /// ## Usage
 ///
-/// ```ignore
+/// ```no_run
+/// use std::collections::HashMap;
+///
+/// use epp_client::config::{EppClientConfig, EppClientConnection};
 /// use epp_client::EppClient;
 /// use epp_client::epp::object::data::{Address, Phone, PostalInfo};
 /// use epp_client::epp::{EppContactCreate, EppContactCreateResponse};
@@ -20,9 +23,23 @@ use serde::{Deserialize, Serialize};
 ///
 /// #[tokio::main]
 /// async fn main() {
-///     // Create an instance of EppClient, specifying the name of the registry as in
-///     // the config file
-///     let mut client = match EppClient::new("verisign").await {
+///     // Create a config
+///     let mut registry: HashMap<String, EppClientConnection> = HashMap::new();
+///     registry.insert(
+///         "registry_name".to_owned(),
+///         EppClientConnection {
+///             host: "example.com".to_owned(),
+///             port: 700,
+///             username: "username".to_owned(),
+///             password: "password".to_owned(),
+///             ext_uris: None,
+///             tls_files: None,
+///         },
+///     );
+///     let config = EppClientConfig { registry };
+///
+///     // Create an instance of EppClient, passing the config and the registry you want to connect to
+///     let mut client = match EppClient::new(&config, "registry_name").await {
 ///         Ok(client) => client,
 ///         Err(e) => panic!("Failed to create EppClient: {}",  e)
 ///     };
@@ -51,6 +68,8 @@ use serde::{Deserialize, Serialize};
 ///     let response = client.transact::<_, EppContactCreateResponse>(&contact_create).await.unwrap();
 ///
 ///     println!("{:?}", response);
+///
+///     client.logout().await.unwrap();
 /// }
 /// ```
 pub type EppContactCreate = EppObject<Command<ContactCreate>>;
@@ -99,8 +118,8 @@ impl EppContactCreate {
             contact: Contact {
                 xmlns: EPP_CONTACT_XMLNS.to_string(),
                 id: id.to_string_value(),
-                postal_info: postal_info,
-                voice: voice,
+                postal_info,
+                voice,
                 fax: None,
                 email: email.to_string_value(),
                 auth_info: data::AuthInfo::new(auth_password),
