@@ -8,8 +8,6 @@ use crate::error;
 
 pub const EPP_XML_HEADER: &str = r#"<?xml version="1.0" encoding="UTF-8" standalone="no"?>"#;
 pub const EPP_XMLNS: &str = "urn:ietf:params:xml:ns:epp-1.0";
-pub const EPP_XMLNS_XSI: &str = "http://www.w3.org/2001/XMLSchema-instance";
-pub const EPP_XSI_SCHEMA_LOCATION: &str = "urn:ietf:params:xml:ns:epp-1.0 epp-1.0.xsd";
 
 pub const EPP_DOMAIN_XMLNS: &str = "urn:ietf:params:xml:ns:domain-1.0";
 pub const EPP_CONTACT_XMLNS: &str = "urn:ietf:params:xml:ns:contact-1.0";
